@@ -15,8 +15,8 @@
 #' @param data Data frame containing dependant variable in the first column and
 #' the others in the rest.
 #' @param ic Information criterion to use.
-#' @param silent If \code{silent=FALSE}, then nothing is silent, everything is
-#' printed out. \code{silent=TRUE} means that nothing is produced.
+#' @param quiet If \code{quiet=FALSE}, then nothing is quiet, everything is
+#' printed out. \code{quiet=TRUE} means that nothing is produced.
 #' @param df Number of degrees of freedom to add (should be used if stepwise is
 #' used on residuals).
 #' @param method Method of correlations calculation. The default is Kendall's
@@ -24,6 +24,8 @@
 #' @param distribution Distribution to pass to \code{alm()}.
 #' @param occurrence what distribution to use for occurrence part. See
 #' \link[greybox]{alm} for details.
+#' @param ... This is temporary and is needed in order to capture "quiet"
+#' parameter if it is provided.
 #'
 #' @return Function returns \code{model} - the final model of the class "alm".
 #' See \link[greybox]{alm} for details of the output.
@@ -57,16 +59,19 @@
 #'
 #' @importFrom stats .lm.fit
 #' @export stepwise
-stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL,
+stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), quiet=TRUE, df=NULL,
                      method=c("pearson","kendall","spearman"),
                      distribution=c("dnorm","dfnorm","dlnorm","dlaplace","ds","dchisq","dlogis",
                                     "plogis","pnorm"),
-                     occurrence=c("none","plogis","pnorm")){
+                     occurrence=c("none","plogis","pnorm"), ...){
 ##### Function that selects variables based on IC and using partial correlations
     if(is.null(df)){
         df <- 0;
     }
 
+    #### This is temporary and needs to be removed at some point! ####
+    quiet[] <- depricator(quiet, list(...));
+
     # Check, whether the response is numeric
     if(is.data.frame(data)){
         if(!is.numeric(data[[1]])){
@@ -118,7 +123,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
     # Define what function to use in the estimation
     if(useALM){
         lmCall <- alm;
-        listToCall <- list(distribution=distribution, checks=FALSE);
+        listToCall <- list(distribution=distribution, fast=TRUE);
     }
     else{
         if(!is.data.frame(data)){
@@ -241,7 +246,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
     testModel <- do.call(lmCall,listToCall);
     # Write down the logLik and take df into account
     logLikValue <- logLik(testModel);
-    attributes(logLikValue)$df <- nParam(logLikValue) + df;
+    attributes(logLikValue)$df <- nparam(logLikValue) + df;
     # Write down the IC. This one needs to be calculated from the logLik
     # in order to take the additional df into account.
     currentIC <- bestIC <- IC(logLikValue);
@@ -251,7 +256,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
     errors[] <- residuals(testModel);
 
     bestFormula <- testFormula;
-    if(!silent){
+    if(!quiet){
         cat("Formula: "); cat(testFormula);
         cat(", IC: "); cat(currentIC); cat("\n\n");
     }
@@ -273,9 +278,9 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
         testModel <- do.call(lmCall,listToCall);
         # Modify logLik
         logLikValue <- logLik(testModel);
-        attributes(logLikValue)$df <- nParam(logLikValue) + df;
+        attributes(logLikValue)$df <- nparam(logLikValue) + df;
         if(attributes(logLikValue)$df >= (obsInsample+1)){
-            if(!silent){
+            if(!quiet){
                 warning("Number of degrees of freedom is greater than number of observations. Cannot proceed.");
             }
             bestICNotFound <- FALSE;
@@ -284,7 +289,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
 
         # Calculate the IC
         currentIC <- IC(logLikValue);
-        if(!silent){
+        if(!quiet){
             cat(paste0("Step ",m-1,". "));
             cat("Formula: "); cat(testFormula);
             cat(", IC: "); cat(currentIC);
@@ -322,7 +327,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
 
         bestModel$distribution <- distribution;
         bestModel$logLik <- logLik(bestModel);
-        bestModel$mu <- bestModel$fitted.values <- bestModel$data[,1] - c(bestModel$residuals);
+        bestModel$mu <- bestModel$fitted <- bestModel$data[,1] - c(bestModel$residuals);
         # This is number of variables + constant + variance
         bestModel$df <- length(varsNames) + 1 + 1;
         bestModel$df.residual <- obsInsample - bestModel$df;
@@ -345,7 +350,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL
                                          data=dataSubstitute,
                                          distribution=distribution,
                                          occurrence=occurrence,
-                                         checks=FALSE),
+                                         fast=TRUE),
                              envir = parent.frame());
         bestModel$call$occurrence <- substitute(occurrence);
         class(bestModel) <- c("alm","greybox");
